@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2021-2023 -- leonerd@leonerd.org.uk
 
-package XS::Parse::Keyword 0.45;
+package XS::Parse::Keyword 0.47;
 
 use v5.14;
 use warnings;
@@ -32,6 +32,8 @@ changes or at least a rebuild of any module that depends on it.
 
 =head1 XS FUNCTIONS
 
+=for highlighter language=c
+
 =head2 boot_xs_parse_keyword
 
    void boot_xs_parse_keyword(double ver);
@@ -172,7 +174,7 @@ specification given by the I<pieces> or I<piece1> field. The result of that
 parsing step is placed into the I<args> or I<arg0> parameter to the invoked
 function, using a C<struct> type consisting of the following fields:
 
-   typedef struct
+   typedef struct {
       union {
          OP *op;
          CV *cv;
@@ -384,18 +386,6 @@ an optree in the I<op> field.
 
 Variants of C<XPK_TERMEXPR> which puts the expression in void or scalar context.
 
-=head2 XPK_PREFIXED_TERMEXPR_ENTERLEAVE
-
-   XPK_PREFIXED_TERMEXPR_ENTERLEAVE(pieces ...)
-
-A variant of C<XPK_TERMEXPR> which expects a sequence pieces first before it
-parses a term expression, similar to how C<XPK_PREFIXED_BLOCK_ENTERLEAVE>
-works. The entire operation is wrapped in an C<ENTER>/C<LEAVE> pair.
-
-This is intended just for use of C<XPK_SETUP> pieces as prefixes. Any other
-pieces which actually parse real input are likely to cause overly-complex,
-subtle, or outright ambiguous grammars, and should be avoided.
-
 =head2 XPK_LISTEXPR, XPK_LISTEXPR_OPT
 
 I<atomic, emits op.>
@@ -409,6 +399,20 @@ an optree in the I<op> field.
 
 Variant of C<XPK_LISTEXPR> which puts the expression in list context.
 
+=head2 XPK_PREFIXED_TERMEXPR_ENTERLEAVE, XPK_PREFIXED_LISTEXPR_ENTERLEAVE
+
+   XPK_PREFIXED_TERMEXPR_ENTERLEAVE(pieces ...)
+   XPK_PREFIXED_LISTEXPR_ENTERLEAVE(pieces ...)
+
+Variants of C<XPK_TERMEXPR> or C<XPK_LISTEXPR> which expect a sequence pieces
+first before it parses a term expression, similar to how
+C<XPK_PREFIXED_BLOCK_ENTERLEAVE> works. The entire operation is wrapped in an
+C<ENTER>/C<LEAVE> pair.
+
+These are intended just for use of C<XPK_SETUP> pieces as prefixes. Any other
+pieces which actually parse real input are likely to cause overly-complex,
+subtle, or outright ambiguous grammars, and should be avoided.
+
 =head2 XPK_IDENT, XPK_IDENT_OPT
 
 I<atomic, can probe, emits sv.>
@@ -450,9 +454,13 @@ Each attribute is expected to be an identifier name, followed by an optional
 value wrapped in parentheses. Whitespace is B<NOT> permitted between the name
 and value, as per standard Perl parsing rules.
 
+=for highlighter language=perl
+
    :attrname
    :attrname(value)
 
+=for highlighter language=c
+
 The I<i> field indicates how many attributes were found. That number of
 additional arguments are then passed, each containing two SVs in the
 I<attr.name> and I<attr.value> fields. This number may be zero.
@@ -523,10 +531,10 @@ operator.
 Various versions of the macro are provided, each using a different selection
 filter to choose certain available infix operators:
 
-   XPK_INFIX_RELATION         # any relational operator
-   XPK_INFIX_EQUALITY         # an equality operator like `==` or `eq`
-   XPK_INFIX_MATCH_NOSMART    # any sort of "match"-like operator, except smartmatch
-   XPK_INFIX_MATCH_SMART      # XPK_INFIX_MATCH_NOSMART plus smartmatch
+   XPK_INFIX_RELATION         // any relational operator
+   XPK_INFIX_EQUALITY         // an equality operator like `==` or `eq`
+   XPK_INFIX_MATCH_NOSMART    // any sort of "match"-like operator, except smartmatch
+   XPK_INFIX_MATCH_SMART      // XPK_INFIX_MATCH_NOSMART plus smartmatch
 
 =head2 XPK_LITERAL
 
