@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2021 -- leonerd@leonerd.org.uk
 
-package XS::Parse::Keyword::Builder 0.45;
+package XS::Parse::Keyword::Builder 0.47;
 
 use v5.14;
 use warnings;
@@ -14,6 +14,8 @@ C<XS::Parse::Keyword::Builder> - build-time support for C<XS::Parse::Keyword>
 
 =head1 SYNOPSIS
 
+=for highlighter language=perl
+
 In F<Build.PL>:
 
    use XS::Parse::Keyword::Builder;
@@ -72,7 +74,9 @@ sub extra_compiler_flags
 
    require File::ShareDir;
    require File::Spec;
-   return "-I" . File::Spec->catdir( File::ShareDir::dist_dir( "XS-Parse-Keyword" ), "include" ),
+   require XS::Parse::Keyword;
+
+   return "-I" . File::Spec->catdir( File::ShareDir::module_dir( "XS::Parse::Keyword" ), "include" ),
       XS::Parse::Keyword::Builder_data->BUILDER_CFLAGS;
 }
 
