@@ -396,6 +396,8 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
   }
   bool is_enterleave = !!(piece->type & XPK_TYPEFLAG_ENTERLEAVE);
 
+  U32 optflag = is_optional ? PARSE_OPTIONAL : 0;
+
   U32 type = piece->type & 0xFFFF;
 
   switch(type) {
@@ -419,7 +421,7 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
       int warnbit = piece->type >> 24;
       if(warnbit && !ckWARN(warnbit))
         return;
-      warn(piece->u.str);
+      warn("%s", piece->u.str);
       return;
     }
 
@@ -508,6 +510,7 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
 
     case XS_PARSE_KEYWORD_ARITHEXPR:
     case XS_PARSE_KEYWORD_TERMEXPR:
+    case XS_PARSE_KEYWORD_LISTEXPR:
     {
       if(is_enterleave)
         ENTER;
@@ -524,7 +527,7 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
       /* TODO: This auto-parens behaviour ought to be tuneable, depend on how
        * many args, open at i=0 and close at i=MAX, etc...
        */
-      if(lex_peek_unichar(0) == '(') {
+      if(type != XS_PARSE_KEYWORD_LISTEXPR && lex_peek_unichar(0) == '(') {
         /* consume a fullexpr and stop at the close paren */
         lex_read_unichar(0);
 
@@ -533,7 +536,7 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
         if(lex_peek_unichar(0) == ')')
           THISARG.op = newOP(OP_STUB, 0);
         else {
-          THISARG.op = parse_fullexpr(0);
+          THISARG.op = parse_fullexpr(optflag);
           CHECK_PARSEFAIL;
 
           lex_read_space(0);
@@ -544,16 +547,19 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
       else {
         switch(type) {
           case XS_PARSE_KEYWORD_ARITHEXPR:
-            THISARG.op = parse_arithexpr(0);
+            THISARG.op = parse_arithexpr(optflag);
             break;
           case XS_PARSE_KEYWORD_TERMEXPR:
-            THISARG.op = parse_termexpr(0);
+            THISARG.op = parse_termexpr(optflag);
+            break;
+          case XS_PARSE_KEYWORD_LISTEXPR:
+            THISARG.op = parse_listexpr(optflag);
             break;
         }
         CHECK_PARSEFAIL;
       }
 
-      if(want)
+      if(want && THISARG.op)
         THISARG.op = op_contextualize(THISARG.op, want);
 
       (*argidx)++;
@@ -564,16 +570,6 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
       return;
     }
 
-    case XS_PARSE_KEYWORD_LISTEXPR:
-      THISARG.op = parse_listexpr(0);
-      CHECK_PARSEFAIL;
-
-      if(want)
-        THISARG.op = op_contextualize(THISARG.op, want);
-
-      (*argidx)++;
-      return;
-
     case XS_PARSE_KEYWORD_IDENT:
       THISARG.sv = lex_scan_ident();
       if(!THISARG.sv && !is_optional)
@@ -671,7 +667,7 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
     }
 
     case XS_PARSE_KEYWORD_VSTRING:
-      THISARG.sv = lex_scan_version(is_optional ? PARSE_OPTIONAL : 0);
+      THISARG.sv = lex_scan_version(optflag);
       (*argidx)++;
       return;
 
@@ -890,7 +886,7 @@ static int parse(pTHX_ OP **op, struct Registration *reg)
   else if(reg->apiver < 2) {
     /* version 1 ->build1 used to take a struct directly, not a pointer thereto */
     int (*v1_build1)(pTHX_ OP **out, XSParseKeywordPiece_v1 arg0, void *hookdata) =
-      (int (*)())hooks->build1;
+      (int (*)(pTHX_ OP **, XSParseKeywordPiece_v1, void *))hooks->build1;
     XSParseKeywordPiece_v1 arg0_v1;
     Copy(args + 0, &arg0_v1, 1, XSParseKeywordPiece_v1);
     ret = (*v1_build1)(aTHX_ op, arg0_v1, reg->hookdata);
